#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pem
version:              0.2.4
visibility:           public
id:                   pem-0.2.4-27OSPi7TFZuEYAhIRu13nz
key:                  pem-0.2.4-27OSPi7TFZuEYAhIRu13nz
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-pem
synopsis:             Privacy Enhanced Mail (PEM) format reader and writer.
description:
    Privacy Enhanced Mail (PEM) format reader and writer. long description

category:             Data
abi:                  4ff34938fac2f6dfcb259bf35e208419
exposed:              True
exposed-modules:      Data.PEM
hidden-modules:       Data.PEM.Parser Data.PEM.Writer Data.PEM.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pem-0.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pem-0.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pem-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pem
hs-libraries:         HSpem-0.2.4-27OSPi7TFZuEYAhIRu13nz
depends:
    base-4.18.2.1 basement-0.0.16-HvTgG10TboKKpCgs2TlMDx
    bytestring-0.11.5.3 memory-0.18.0-6zo36PbRecTK4fqbBnx0f5

haddock-interfaces:   /usr/share/doc/haskell-pem/html/pem.haddock
haddock-html:         /usr/share/doc/haskell-pem/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

